/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core.internals;

import com.silverwrist.venice.security.AuditRecord;

public class EnvUser extends EnvEngine
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private UserBackend user;    // the user backend object

  /*--------------------------------------------------------------------------------
   * Constructors
   *--------------------------------------------------------------------------------
   */

  public EnvUser(EnvEngine parent, UserBackend user)
  {
    super(parent);
    this.user = user;

  } // end constructor

  protected EnvUser(EnvUser other)
  {
    super(other);
    this.user = other.user;

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public final UserBackend getUser()
  {
    return user;

  } // end getUser

  public final int getUserID()
  {
    return user.realUID();

  } // end getUserID

  public AuditRecord newAudit(int type, String data1, String data2, String data3, String data4)
  {
    return new AuditRecord(type,getUserID(),user.userRemoteAddress(),data1,data2,data3,data4);

  } // end newAudit

  public AuditRecord newAudit(int type, String data1, String data2, String data3)
  {
    return new AuditRecord(type,getUserID(),user.userRemoteAddress(),data1,data2,data3);

  } // end newAudit

  public AuditRecord newAudit(int type, String data1, String data2)
  {
    return new AuditRecord(type,getUserID(),user.userRemoteAddress(),data1,data2);

  } // end newAudit

  public AuditRecord newAudit(int type, String data1)
  {
    return new AuditRecord(type,getUserID(),user.userRemoteAddress(),data1);

  } // end newAudit

  public AuditRecord newAudit(int type)
  {
    return new AuditRecord(type,getUserID(),user.userRemoteAddress());

  } // end newAudit

} // end class EnvUser
